package com.ynet.life.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.math.BigDecimal;
import java.sql.Connection;
import java.util.ArrayList;
import java.util.List;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/CalculatePermitAuditResultAction.class */
public class CalculatePermitAuditResultAction extends LifeJDBCAction {
    private String financeReqNoField;
    private String productFlowNoField;
    private String auditTypeField;
    private String iCollName;
    private static final String QUERY_APPPAR_SQL = "SELECT RCC_ATTTIME FROM FSP_REQ_CONF_CONTROL WHERE RCC_TYPE ='11' AND RCC_FINANCEID =?";
    private static final String INSERT_OPE_SQL = "INSERT INTO FSP_REQ_OPE_FLOW (ROF_FLOWNO,ROF_FINANCEID,ROF_REQNO,ROF_CORNO,ROF_CORNAME,ROF_ORGCODE,ROF_ORGTYPE,ROF_USERNO,ROF_USERNAME,ROF_FLOWSTT,ROF_OPSTT,ROF_REQSTT,ROF_DESC,ROF_REQRELFLOWNO) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
    private static final String INSERT_REL_SQL = "INSERT INTO FSP_REQ_COR_REL_SZYQ (RCR_FLOWNO,RCR_REQNO,RCR_FINANCEID,RCR_USERNO,RCR_FLOWSTT,RCR_OPSTT) VALUES (?,?,?,?,?,?)";
    private static final String QUERY_ADMIN_SQL = "SELECT ATR_CREDITSCORE,ATR_COMNUMBER,ATR_SOCIALNUMBER,ATR_REGISTCAPITAL,ATR_TAXPAYMENT,ATR_TOTALASSETS,ATR_OWNERSEQUITY,ATR_REVENUE,ATR_NETPROFITS,ATR_TOTALLIABILITY,ATR_LEVERAGE,ATR_SMLOANFANBALANCE,ATR_FINANCEGUAAMOUNT,ATR_QUALIFICATION,ATR_INDUSTRY,ATR_INDUSSTRUCTURE FROM ENGINE_ACCESS_AUDIT_APPPAR WHERE ATR_TYPE ='1' AND ATR_STT='0'";
    private static final String QUERY_BRANCH_SQL = "SELECT ATR_CREDITSCORE,ATR_COMNUMBER,ATR_SOCIALNUMBER,ATR_REGISTCAPITAL,ATR_TAXPAYMENT,ATR_TOTALASSETS,ATR_OWNERSEQUITY,ATR_REVENUE,ATR_NETPROFITS,ATR_TOTALLIABILITY,ATR_LEVERAGE,ATR_SMLOANFANBALANCE,ATR_FINANCEGUAAMOUNT,ATR_QUALIFICATION,ATR_INDUSTRY,ATR_INDUSSTRUCTURE FROM ENGINE_ACCESS_AUDIT_APPPAR WHERE ATR_FINANCEID =? AND ATR_TYPE='2' AND ATR_STT='0'";
    private static final String QUERY_PRODUCT_SQL = "SELECT ATR_CREDITSCORE,ATR_COMNUMBER,ATR_SOCIALNUMBER,ATR_REGISTCAPITAL,ATR_TAXPAYMENT,ATR_TOTALASSETS,ATR_OWNERSEQUITY,ATR_REVENUE,ATR_NETPROFITS,ATR_TOTALLIABILITY,ATR_LEVERAGE,ATR_SMLOANFANBALANCE,ATR_FINANCEGUAAMOUNT,ATR_QUALIFICATION,ATR_INDUSTRY,ATR_INDUSSTRUCTURE FROM ENGINE_ACCESS_AUDIT_APPPAR WHERE ATR_PROFLOWNO =? AND ATR_TYPE='3' AND ATR_STT='0'";
    private static final String INSERT_SQL = "INSERT INTO ENGINE_ACCESS_AUDIT_RESULT (AAR_FLOWNO,AAR_REQNO,AAR_PROFLOWNO,AAR_FINANCEID,AAR_ISACCESS,AAR_REFULEREASON) VALUES (?,?,?,?,?,?)";

    public String execute(Context context) throws GENEException {
        IndexedCollection userInfoIcoll = context.getDataElement("userInfoList");
        String corNo = (String) context.getDataValue("corNo");
        String corName = (String) context.getDataValue("corName");
        String corOrgCode = (String) context.getDataValue("corOrgCode");
        IndexedCollection branchIcoll = context.getDataElement(this.iCollName);
        String financeReqNo = (String) context.getDataValue(this.financeReqNoField);
        String productFlowNo = (String) context.getDataValue(this.productFlowNoField);
        String creditScore = (String) context.getDataValue("pba_creditScore");
        String companyNumber = (String) context.getDataValue("pba_comNumber");
        String socialNumber = (String) context.getDataValue("pba_socialNumber");
        String registCapital = (String) context.getDataValue("pba_registCapital");
        String taxPayment = (String) context.getDataValue("pba_taxpayment");
        String totalAssets = (String) context.getDataValue("pba_totalAssets");
        String ownersEquity = (String) context.getDataValue("pba_ownerSequity");
        String revenue = (String) context.getDataValue("pba_revenue");
        String netProfits = (String) context.getDataValue("pba_netProfits");
        String totalLiability = (String) context.getDataValue("pba_totalLibaility");
        String legeRage = (String) context.getDataValue("pba_leverage");
        String smLoanFinance = (String) context.getDataValue("pba_smloanfanbalance");
        String financeGuaAmount = (String) context.getDataValue("pba_smprofanbalance");
        String quaLification = (String) context.getDataValue("pba_qualification");
        String induStry = (String) context.getDataValue("pba_industry");
        String industrialStructure = (String) context.getDataValue("industrialStructure");
        Connection connection = null;
        boolean result = true;
        StringBuilder errorMsg = new StringBuilder("");
        try {
            try {
                connection = LifeDBAccess.getConnection(getDataSource());
                List<String> compareList = new ArrayList<>();
                List<String> resultAdminList = LifeDBAccess.querySingleResult(connection, QUERY_ADMIN_SQL, (List) null, 16);
                for (int j = 0; j < branchIcoll.size(); j++) {
                    String financeBranchNo = (String) ((KeyedCollection) branchIcoll.get(j)).getDataValue("financeBranchNo");
                    ArrayList<String> branchList = new ArrayList<>();
                    branchList.add(financeBranchNo);
                    ArrayList<String> productList = new ArrayList<>();
                    productList.add(productFlowNo);
                    List<String> resulBranchtList = LifeDBAccess.querySingleResult(connection, QUERY_BRANCH_SQL, branchList, 16);
                    if ("1".equals(this.auditTypeField)) {
                        List<String> resulProductList = LifeDBAccess.querySingleResult(connection, QUERY_PRODUCT_SQL, productList, 16);
                        if (resulProductList.size() != 0) {
                            for (int i = 0; i < resulProductList.size(); i++) {
                                if (!"".equals(resulProductList.get(i)) && resulProductList.get(i) != null) {
                                    compareList.add(resulProductList.get(i));
                                } else if (resulBranchtList.size() != 0) {
                                    if (!"".equals(resulBranchtList.get(i)) && resulBranchtList.get(i) != null) {
                                        compareList.add(resulBranchtList.get(i));
                                    } else if (resultAdminList.size() == 0) {
                                        compareList.add("");
                                    } else if (resultAdminList.get(i) != null) {
                                        compareList.add(resultAdminList.get(i));
                                    } else {
                                        compareList.add("");
                                    }
                                } else if (resultAdminList.size() == 0) {
                                    compareList.add("");
                                } else if (resultAdminList.get(i) != null) {
                                    compareList.add(resultAdminList.get(i));
                                } else {
                                    compareList.add("");
                                }
                            }
                        } else if (resulBranchtList.size() != 0) {
                            for (int i2 = 0; i2 < resulBranchtList.size(); i2++) {
                                if (!"".equals(resulBranchtList.get(i2)) && resulBranchtList.get(i2) != null) {
                                    compareList.add(resulBranchtList.get(i2));
                                } else if (resultAdminList.size() == 0) {
                                    compareList.add("");
                                } else if (resultAdminList.get(i2) != null) {
                                    compareList.add(resultAdminList.get(i2));
                                } else {
                                    compareList.add("");
                                }
                            }
                        } else {
                            compareList = resultAdminList;
                        }
                    } else if ("2".equals(this.auditTypeField)) {
                        if (resulBranchtList.size() != 0) {
                            for (int i3 = 0; i3 < resulBranchtList.size(); i3++) {
                                if (!"".equals(resulBranchtList.get(i3)) && resulBranchtList.get(i3) != null) {
                                    compareList.add(resulBranchtList.get(i3));
                                } else if (resultAdminList.size() == 0) {
                                    compareList.add("");
                                } else if (resultAdminList.get(i3) != null) {
                                    compareList.add(resultAdminList.get(i3));
                                } else {
                                    compareList.add("");
                                }
                            }
                        } else {
                            compareList = resultAdminList;
                        }
                    }
                    System.out.println("compareList------------------".concat(String.valueOf(compareList)));
                    try {
                        try {
                            if (compareList.size() != 0) {
                                if (!"".equals(compareList.get(0)) && compareList.get(0) != null && !"".equals(creditScore) && creditScore != null && new BigDecimal(creditScore).compareTo(new BigDecimal(compareList.get(0))) == -1) {
                                    result = false;
                                    errorMsg.append("信用评分低于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(1)) && compareList.get(1) != null && !"".equals(companyNumber) && companyNumber != null && Integer.parseInt(companyNumber) < Integer.parseInt(compareList.get(1))) {
                                    result = false;
                                    errorMsg.append("公司人数低于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(2)) && compareList.get(2) != null && !"".equals(socialNumber) && socialNumber != null && Integer.parseInt(socialNumber) < Integer.parseInt(compareList.get(2))) {
                                    result = false;
                                    errorMsg.append("社保缴交人数低于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(3)) && compareList.get(3) != null && !"".equals(registCapital) && registCapital != null && new BigDecimal(registCapital).compareTo(new BigDecimal(compareList.get(3))) == -1) {
                                    result = false;
                                    errorMsg.append("注册资本低于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(4)) && compareList.get(4) != null && !"".equals(taxPayment) && taxPayment != null && new BigDecimal(taxPayment).compareTo(new BigDecimal(compareList.get(4))) == -1) {
                                    result = false;
                                    errorMsg.append("纳税合计低于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(5)) && compareList.get(5) != null && !"".equals(totalAssets) && totalAssets != null && new BigDecimal(totalAssets).compareTo(new BigDecimal(compareList.get(5))) == -1) {
                                    result = false;
                                    errorMsg.append("资产总计低于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(6)) && compareList.get(6) != null && !"".equals(ownersEquity) && ownersEquity != null && new BigDecimal(ownersEquity).compareTo(new BigDecimal(compareList.get(6))) == -1) {
                                    result = false;
                                    errorMsg.append("所有者权益合计低于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(7)) && compareList.get(7) != null && !"".equals(revenue) && revenue != null && new BigDecimal(revenue).compareTo(new BigDecimal(compareList.get(7))) == -1) {
                                    result = false;
                                    errorMsg.append("主营业务收入低于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(8)) && compareList.get(8) != null && !"".equals(netProfits) && netProfits != null && new BigDecimal(netProfits).compareTo(new BigDecimal(compareList.get(8))) == -1) {
                                    result = false;
                                    errorMsg.append("净利润收入低于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(9)) && compareList.get(9) != null && !"".equals(totalLiability) && totalLiability != null && new BigDecimal(totalLiability).compareTo(new BigDecimal(compareList.get(9))) == 1) {
                                    result = false;
                                    errorMsg.append("负债合计高于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(10)) && compareList.get(10) != null && !"".equals(legeRage) && legeRage != null && new BigDecimal(legeRage).compareTo(new BigDecimal(compareList.get(10))) == 1) {
                                    result = false;
                                    errorMsg.append("资产负债率大于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(11)) && compareList.get(11) != null && !"".equals(smLoanFinance) && smLoanFinance != null && new BigDecimal(smLoanFinance).compareTo(new BigDecimal(compareList.get(11))) == 1) {
                                    result = false;
                                    errorMsg.append("未结清的小额贷款金额大于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(12)) && compareList.get(12) != null && !"".equals(financeGuaAmount) && financeGuaAmount != null && new BigDecimal(financeGuaAmount).compareTo(new BigDecimal(compareList.get(12))) == 1) {
                                    result = false;
                                    errorMsg.append("未解保的融资担保金额大于设置的参数大小;\n");
                                }
                                if (!"".equals(compareList.get(13)) && !"".equals(quaLification) && quaLification != null) {
                                    String[] array = compareList.get(13).split(",");
                                    int count = 0;
                                    int i4 = 0;
                                    while (true) {
                                        if (i4 >= array.length) {
                                            break;
                                        }
                                        if (array[i4].equals(quaLification)) {
                                            count = 0 + 1;
                                            break;
                                        }
                                        i4++;
                                    }
                                    if (count == 0) {
                                        result = false;
                                        errorMsg.append("不满足设置的资质类型;\n");
                                    }
                                }
                                if (!"".equals(compareList.get(14)) && !"".equals(induStry) && induStry != null) {
                                    String[] array2 = compareList.get(14).split(",");
                                    int count2 = 0;
                                    int i5 = 0;
                                    while (true) {
                                        if (i5 >= array2.length) {
                                            break;
                                        }
                                        if (array2[i5].equals(induStry)) {
                                            count2 = 0 + 1;
                                            break;
                                        }
                                        i5++;
                                    }
                                    if (count2 == 0) {
                                        result = false;
                                        errorMsg.append("不满足设置的行内分类;\n");
                                    }
                                }
                                if (!"".equals(compareList.get(15)) && !"".equals(industrialStructure) && industrialStructure != null) {
                                    String[] array3 = compareList.get(15).split(",");
                                    int count3 = 0;
                                    int i6 = 0;
                                    while (true) {
                                        if (i6 >= array3.length) {
                                            break;
                                        }
                                        if (array3[i6].equals(industrialStructure)) {
                                            count3 = 0 + 1;
                                            break;
                                        }
                                        i6++;
                                    }
                                    if (count3 == 0) {
                                        result = false;
                                        errorMsg.append("不满足设置的产业结构;\n");
                                    }
                                }
                            }
                            List<String> inputList = new ArrayList<>();
                            inputList.add(getFlowNo());
                            inputList.add(financeReqNo);
                            inputList.add(productFlowNo);
                            inputList.add(financeBranchNo);
                            inputList.add(result ? "1" : "0");
                            inputList.add(errorMsg.toString());
                            LifeDBAccess.executeSQLUpdate(connection, INSERT_SQL, inputList);
                            List querySingleResult = LifeDBAccess.querySingleResult(connection, QUERY_APPPAR_SQL, branchList, 1);
                            if (!result && querySingleResult.size() != 0 && "0".equals(querySingleResult.get(0))) {
                                for (int i7 = 0; i7 < userInfoIcoll.size(); i7++) {
                                    KeyedCollection userInfoKColl = (KeyedCollection) userInfoIcoll.get(i7);
                                    String financeId = (String) userInfoKColl.getDataValue("financeId");
                                    String userId = (String) userInfoKColl.getDataValue("userId");
                                    String userName = (String) userInfoKColl.getDataValue("userName");
                                    if (financeBranchNo.equals(financeId)) {
                                        String reqBranchFlowNo = getFlowNo();
                                        List<String> inputList2 = new ArrayList<>();
                                        inputList2.add(reqBranchFlowNo);
                                        inputList2.add(financeReqNo);
                                        inputList2.add(financeId);
                                        inputList2.add(userId);
                                        inputList2.add("1");
                                        inputList2.add("13");
                                        LifeDBAccess.executeSQLUpdate(connection, INSERT_REL_SQL, inputList2);
                                        List<String> inputList3 = new ArrayList<>();
                                        inputList3.add(getFlowNo());
                                        inputList3.add(financeId);
                                        inputList3.add(financeReqNo);
                                        inputList3.add(corNo);
                                        inputList3.add(corName);
                                        inputList3.add(corOrgCode);
                                        inputList3.add("2");
                                        inputList3.add(userId);
                                        inputList3.add(userName);
                                        inputList3.add("1");
                                        inputList3.add("13");
                                        inputList3.add("01");
                                        inputList3.add("准入审核不通过");
                                        inputList3.add(reqBranchFlowNo);
                                        LifeDBAccess.executeSQLUpdate(connection, INSERT_OPE_SQL, inputList3);
                                    }
                                }
                            }
                            result = true;
                            errorMsg = new StringBuilder("");
                        } finally {
                        }
                    } catch (Exception unused) {
                        errorMsg.append("不识别的设置信息;\n");
                        List<String> inputList4 = new ArrayList<>();
                        inputList4.add(getFlowNo());
                        inputList4.add(financeReqNo);
                        inputList4.add(productFlowNo);
                        inputList4.add(financeBranchNo);
                        inputList4.add("0");
                        inputList4.add(errorMsg.toString());
                        LifeDBAccess.executeSQLUpdate(connection, INSERT_SQL, inputList4);
                        List<String> resultAppparList = LifeDBAccess.querySingleResult(connection, QUERY_APPPAR_SQL, branchList, 1);
                        if (resultAppparList.size() != 0 && "0".equals(resultAppparList.get(0))) {
                            for (int i8 = 0; i8 < userInfoIcoll.size(); i8++) {
                                KeyedCollection userInfoKColl2 = (KeyedCollection) userInfoIcoll.get(i8);
                                String financeId2 = (String) userInfoKColl2.getDataValue("financeId");
                                String userId2 = (String) userInfoKColl2.getDataValue("userId");
                                String userName2 = (String) userInfoKColl2.getDataValue("userName");
                                if (financeBranchNo.equals(financeId2)) {
                                    String reqBranchFlowNo2 = getFlowNo();
                                    List<String> inputList22 = new ArrayList<>();
                                    inputList22.add(reqBranchFlowNo2);
                                    inputList22.add(financeReqNo);
                                    inputList22.add(financeId2);
                                    inputList22.add(userId2);
                                    inputList22.add("1");
                                    inputList22.add("13");
                                    LifeDBAccess.executeSQLUpdate(connection, INSERT_REL_SQL, inputList22);
                                    List<String> inputList32 = new ArrayList<>();
                                    inputList32.add(getFlowNo());
                                    inputList32.add(financeId2);
                                    inputList32.add(financeReqNo);
                                    inputList32.add(corNo);
                                    inputList32.add(corName);
                                    inputList32.add(corOrgCode);
                                    inputList32.add("2");
                                    inputList32.add(userId2);
                                    inputList32.add(userName2);
                                    inputList32.add("1");
                                    inputList32.add("13");
                                    inputList32.add("01");
                                    inputList32.add("准入审核不通过");
                                    inputList32.add(reqBranchFlowNo2);
                                    LifeDBAccess.executeSQLUpdate(connection, INSERT_OPE_SQL, inputList32);
                                }
                            }
                        }
                        result = true;
                        errorMsg = new StringBuilder("");
                    }
                }
                LifeDBAccess.releaseConnection(getDataSource(), connection);
                return "0";
            } catch (TranFailException se) {
                TranFailException tfe = new TranFailException(se);
                Trace.logError("LOAF", se.getMessage(), se);
                context.put("GENEException", tfe);
                throw tfe;
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection(getDataSource(), connection);
            throw th;
        }
    }

    public String getFlowNo() {
        return String.valueOf(IdWorker.getInstance().nextId());
    }

    public void setICollName(String collName) {
        this.iCollName = collName;
    }

    public void setFinanceReqNoField(String financeReqNoField) {
        this.financeReqNoField = financeReqNoField;
    }

    public void setProductFlowNoField(String productFlowNoField) {
        this.productFlowNoField = productFlowNoField;
    }

    public void setAuditTypeField(String auditTypeField) {
        this.auditTypeField = auditTypeField;
    }
}
